==> libphidget22java-1.0.0.20171019.tar.gz: libphidget22java-1.0.0.20171019/src/jni/com_phidget22_DistanceSensor.c <==
/*
 * This file is part of libphidget22java
 *
 * Copyright 2015 Phidgets Inc <patrick@phidgets.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see
 * <http://www.gnu.org/licenses/>
 */

#include "phidget_jni.h"
#include "com_phidget22_DistanceSensor.h"
#include "com_phidget22_DistanceSensorBase.h"

extern jfieldID phidget_handle_fid;

void com_phidget22_DistanceSensor_OnLoad(JNIEnv *env) { }

JNIEXPORT jobject JNICALL Java_com_phidget22_DistanceSensorBase_getSonarReflections(JNIEnv * env, jobject obj) {
	PhidgetDistanceSensorHandle h = (PhidgetDistanceSensorHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	DistanceSensorSonarReflections reflections;
	int error;

	reflections.count = 8;
	if ((error = PhidgetDistanceSensor_getSonarReflections(h, reflections.distances, reflections.amplitudes, &reflections.count)))
		PH_THROW(error);
	return DistanceSensorSonarReflections_to_jobject(env, &reflections);
}

==> libphidget22java-1.0.0.20171212.tar.gz: libphidget22java-1.0.0.20171212/src/jni/com_phidget22_DistanceSensor.c <==
/*
 * This file is part of libphidget22java
 *
 * Copyright 2015 Phidgets Inc <patrick@phidgets.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see
 * <http://www.gnu.org/licenses/>
 */

#include "phidget_jni.h"
#include "com_phidget22_DistanceSensor.h"
#include "com_phidget22_DistanceSensorBase.h"

extern jfieldID phidget_handle_fid;

void com_phidget22_DistanceSensor_OnLoad(JNIEnv *env) { }

JNIEXPORT jobject JNICALL Java_com_phidget22_DistanceSensorBase_getSonarReflections(JNIEnv * env, jobject obj) {
	PhidgetDistanceSensorHandle h = (PhidgetDistanceSensorHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	DistanceSensorSonarReflections reflections;
	int error;

	reflections.count = 8;
	if ((error = PhidgetDistanceSensor_getSonarReflections(h, reflections.distances, reflections.amplitudes, &reflections.count))) {
		PH_THROW(error);
		return NULL;
	}
	return DistanceSensorSonarReflections_to_jobject(env, &reflections);
}
